@@ -4,7 +4,7 @@
 #define H_GNOME_SYSTEM_MONITOR_UTIL_1123178725
 
 #include <glib.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gtk/gtk.h>
 #include <stddef.h>
 #include <cstring>
 #include <string>
@@ -33,11 +33,6 @@ procman_make_label_for_mmaps_or_ofiles(const char *format,
 					     const char *process_name,
 					     unsigned pid);
 
-
-gchar*
-SI_gnome_vfs_format_file_size_for_display (GnomeVFSFileSize size, GnomeVFSFileSize max = 0);
-
-
 gboolean
 load_symbols(const char *module, ...) G_GNUC_NULL_TERMINATED;
 
@@ -50,6 +45,11 @@ procman_debug_real(const char *file, int line, const char *func,
 
 inline string make_string(char *c_str)
 {
+	if (!c_str) {
+		procman_debug("NULL string");
+		return string();
+	}
+
 	string s(c_str);
 	g_free(c_str);
 	return s;
@@ -140,8 +140,9 @@ namespace procman
   }
 
 
+  gchar* format_size(guint64 size, guint64 max = 0);
 
-  std::string format_rate(GnomeVFSFileSize rate, GnomeVFSFileSize max_rate = 0);
+  std::string format_rate(guint64 rate, guint64 max_rate = 0);
 }
 
 
